<?php
require 'inc/baglan.php'; // Veritabanı bağlantısı

session_start(); // Start the session to manage user authentication

// Function to sanitize input values
function sanitize_input($data) {
    return htmlspecialchars(trim($data));
}

// Check if the user is logged in and has the correct permission
function check_user_permission() {
    // Check if user is logged in by checking session data (assuming 'user_id' and 'user_role' are stored in session)
    if (!isset($_SESSION['eposta'])) {
        // Redirect to index.php if not logged in
        header('Location: index.php');
        exit();
    }
}

// Call this function to ensure the user has the right permissions before proceeding
check_user_permission();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // POST verilerini al ve sanitize et
    $komponentId = sanitize_input($_POST['komponent_id']);
    $komponentAd = sanitize_input($_POST['komponent_ad']);
    $ekBilgi = sanitize_input($_POST['ek_bilgi']);
    $kategoriId = sanitize_input($_POST['kategori_id']);
    $tedarikciId = sanitize_input($_POST['tedarikci_id']);
    $ureticiId = sanitize_input($_POST['uretici_id']);
    $lokasyonId = sanitize_input($_POST['lokasyon_id']);
    $paketId = sanitize_input($_POST['paket_id']);
    $adetId = sanitize_input($_POST['adet_id']);

    try {
        // Komponent tablosunda güncelleme işlemi
        $query = "
            UPDATE komponent
            SET ad = :komponent_ad, ek_bilgi = :ek_bilgi, kategori_id = :kategori_id,
                tedarikci_id = :tedarikci_id, uretici_id = :uretici_id, lokasyon_id = :lokasyon_id, paket_id = :paket_id, adet = :adet_id
            WHERE id = :komponent_id
        ";

        $stmt = $baglantim->prepare($query);
        $stmt->bindParam(':komponent_ad', $komponentAd, PDO::PARAM_STR);
        $stmt->bindParam(':ek_bilgi', $ekBilgi, PDO::PARAM_STR);
        $stmt->bindParam(':kategori_id', $kategoriId, PDO::PARAM_INT);
        $stmt->bindParam(':tedarikci_id', $tedarikciId, PDO::PARAM_INT);
        $stmt->bindParam(':uretici_id', $ureticiId, PDO::PARAM_INT);
        $stmt->bindParam(':komponent_id', $komponentId, PDO::PARAM_INT);
        $stmt->bindParam(':lokasyon_id', $lokasyonId, PDO::PARAM_INT);
        $stmt->bindParam(':paket_id', $paketId, PDO::PARAM_INT);
        $stmt->bindParam(':adet_id', $adetId, PDO::PARAM_INT);
        $stmt->execute();

        // Kategori, Lokasyon ve Paket hiyerarşisini almak için CTE sorgusu
        $cteQuery = $baglantim->prepare("
        WITH RECURSIVE kategori_cte AS (
            SELECT k.id, k.ad, CAST(k.ad AS CHAR(255)) AS yol, k.kategori_id AS parent_id, 0 AS derinlik
            FROM kategori k WHERE k.id = :kategori_id
            UNION ALL
            SELECT parent.id, parent.ad, CONCAT(parent.ad, ' > ', kategori_cte.yol), parent.kategori_id, kategori_cte.derinlik + 1
            FROM kategori parent JOIN kategori_cte ON kategori_cte.parent_id = parent.id
        ),
        lokasyon_cte AS (
            SELECT l.id, l.ad, CAST(l.ad AS CHAR(255)) AS yol, l.lokasyon_id, 0 AS derinlik
            FROM lokasyon l WHERE l.id = :lokasyon_id
            UNION ALL
            SELECT parent.id, parent.ad, CONCAT(parent.ad, ' > ', lokasyon_cte.yol), parent.lokasyon_id, lokasyon_cte.derinlik + 1
            FROM lokasyon parent JOIN lokasyon_cte ON lokasyon_cte.lokasyon_id = parent.id
        ),
        paket_cte AS (
            SELECT p.id, p.ad, CAST(p.ad AS CHAR(255)) AS yol, p.paket_id, 0 AS derinlik
            FROM paket p WHERE p.id = :paket_id
            UNION ALL
            SELECT parent.id, parent.ad, CONCAT(parent.ad, ' > ', paket_cte.yol), parent.paket_id, paket_cte.derinlik + 1
            FROM paket parent JOIN paket_cte ON paket_cte.paket_id = parent.id
        )
        SELECT 
            (SELECT yol FROM kategori_cte ORDER BY derinlik DESC LIMIT 1) AS tam_kategori,
            (SELECT ad FROM kategori_cte ORDER BY derinlik DESC LIMIT 1) AS kategori,
            (SELECT yol FROM lokasyon_cte ORDER BY derinlik DESC LIMIT 1) AS tam_lokasyon,
            (SELECT yol FROM paket_cte ORDER BY derinlik DESC LIMIT 1) AS tam_paket;
        ");

        $cteQuery->bindParam(':kategori_id', $kategoriId, PDO::PARAM_INT);
        $cteQuery->bindParam(':lokasyon_id', $lokasyonId, PDO::PARAM_INT);
        $cteQuery->bindParam(':paket_id', $paketId, PDO::PARAM_INT);
        $cteQuery->execute();

        $sonuc = $cteQuery->fetch(PDO::FETCH_ASSOC);

        // Ajax ile post edilen verilere bilgi gönderir ve tablonun ilgili satırını sayfa yenilenmeden günceller
        echo json_encode([
            'status' => 'success',
            'message' => 'Component updated successfully!',
            'data' => [
                'komponent_ad' => $komponentAd,
                'ek_bilgi' => $ekBilgi,
                'tam_kategori' => $sonuc['tam_kategori'] ?? 'Bilinmiyor',
                'kategori' => $sonuc['kategori'] ?? 'Bilinmiyor',
                'tam_lokasyon' => $sonuc['tam_lokasyon'] ?? 'Bilinmiyor',
                'tam_paket' => $sonuc['tam_paket'] ?? 'Bilinmiyor',
                'tedarikci_ad' => getTedarikciAd($tedarikciId, $baglantim),
                'uretici_ad' => getUreticiAd($ureticiId, $baglantim),
                'adet' => $adetId
            ]
        ]);
    } catch (PDOException $e) {
        // Error handling improved, don't expose detailed error messages to the user
        echo json_encode(['status' => 'error', 'message' => 'Hata oluştu.']);
        error_log('Database Error: ' . $e->getMessage());  // Log the actual error for debugging purposes
    }
}

// Yardımcı fonksiyonlar
function getTedarikciAd($tedarikciId, $db) {
    $stmt = $db->prepare("SELECT ad FROM tedarikci WHERE id = :tedarikci_id");
    $stmt->bindParam(':tedarikci_id', $tedarikciId, PDO::PARAM_INT);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    return $row ? $row['ad'] : 'Tedarikçi Bulunamadı';
}

function getUreticiAd($ureticiId, $db) {
    $stmt = $db->prepare("SELECT ad FROM uretici WHERE id = :uretici_id");
    $stmt->bindParam(':uretici_id', $ureticiId, PDO::PARAM_INT);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    return $row ? $row['ad'] : 'Üretici Bulunamadı';
}
?>
